import tables

_layout_desc = {
    # Typical prep output
    "PrepData": {
        'timestamp': tables.Int64Col(pos=1),
        'p1': tables.Float32Col(pos=2),
        'q1': tables.Float32Col(pos=3),
        'p3': tables.Float32Col(pos=4),
        'q3': tables.Float32Col(pos=5),
        'p5': tables.Float32Col(pos=6),
        'q5': tables.Float32Col(pos=7),
        'p7': tables.Float32Col(pos=8),
        'q7': tables.Float32Col(pos=9),
        },
    
    # Raw data
    "RawData": {
        'timestamp': tables.Int64Col(pos=1),
        'va': tables.UInt16Col(pos=2),
        'vb': tables.UInt16Col(pos=3),
        'vc': tables.UInt16Col(pos=4),
        'ia': tables.UInt16Col(pos=5),
        'ib': tables.UInt16Col(pos=6),
        'ic': tables.UInt16Col(pos=7),
        },

    # Raw data plus 60 Hz notched current
    "RawNotchedData": {
        'timestamp': tables.Int64Col(pos=1),
        'va': tables.UInt16Col(pos=2),
        'vb': tables.UInt16Col(pos=3),
        'vc': tables.UInt16Col(pos=4),
        'ia': tables.UInt16Col(pos=5),
        'ib': tables.UInt16Col(pos=6),
        'ic': tables.UInt16Col(pos=7),
        'notch_ia': tables.UInt16Col(pos=8),
        'notch_ib': tables.UInt16Col(pos=9),
        'notch_ic': tables.UInt16Col(pos=10),
        },
}

def layout_to_desc(layout):
    """Return a tables.Description corresponding to the given layout string"""
    return tables.Description(_layout_desc[layout])

def desc_to_layout(match_desc):
    """
    Match a tables.Description to our fixed list of layouts, and
    return a string reprensenting the one that matched, or None
    if nothing matches.

    This isn't very efficient or even very good.
    """
    for layout in _layout_desc.keys():
        if repr(layout_to_desc(layout)) == repr(match_desc):
            return layout
    return None
